# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PortModificationTriggerAttributes(Base):
	"""The PortModificationTriggerAttributes class encapsulates a required portModificationTriggerAttributes node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PortModificationTriggerAttributes property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'portModificationTriggerAttributes'

	def __init__(self, parent):
		super(PortModificationTriggerAttributes, self).__init__(parent)

	@property
	def LinkFeature(self):
		"""An instance of the LinkFeature class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linkfeature.LinkFeature)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linkfeature import LinkFeature
		return LinkFeature(self)._select()

	@property
	def LinkMode(self):
		"""An instance of the LinkMode class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linkmode.LinkMode)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linkmode import LinkMode
		return LinkMode(self)._select()

	@property
	def LinkType(self):
		"""An instance of the LinkType class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linktype.LinkType)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.linktype import LinkType
		return LinkType(self)._select()

	@property
	def AdvertisedFeatures(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('advertisedFeatures')
	@AdvertisedFeatures.setter
	def AdvertisedFeatures(self, value):
		self._set_attribute('advertisedFeatures', value)

	@property
	def DoNotSendPacketIn(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('doNotSendPacketIn')
	@DoNotSendPacketIn.setter
	def DoNotSendPacketIn(self, value):
		self._set_attribute('doNotSendPacketIn', value)

	@property
	def DropAllPackets(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('dropAllPackets')
	@DropAllPackets.setter
	def DropAllPackets(self, value):
		self._set_attribute('dropAllPackets', value)

	@property
	def DropForwardedPackets(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('dropForwardedPackets')
	@DropForwardedPackets.setter
	def DropForwardedPackets(self, value):
		self._set_attribute('dropForwardedPackets', value)

	@property
	def EnableAdvertiseFeature(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableAdvertiseFeature')
	@EnableAdvertiseFeature.setter
	def EnableAdvertiseFeature(self, value):
		self._set_attribute('enableAdvertiseFeature', value)

	@property
	def EnableEthernetAddress(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableEthernetAddress')
	@EnableEthernetAddress.setter
	def EnableEthernetAddress(self, value):
		self._set_attribute('enableEthernetAddress', value)

	@property
	def EnablePortConfig(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enablePortConfig')
	@EnablePortConfig.setter
	def EnablePortConfig(self, value):
		self._set_attribute('enablePortConfig', value)

	@property
	def EnablePortModPortFeatures(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enablePortModPortFeatures')
	@EnablePortModPortFeatures.setter
	def EnablePortModPortFeatures(self, value):
		self._set_attribute('enablePortModPortFeatures', value)

	@property
	def EnablePortNumber(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enablePortNumber')
	@EnablePortNumber.setter
	def EnablePortNumber(self, value):
		self._set_attribute('enablePortNumber', value)

	@property
	def EthernetAddress(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('ethernetAddress')
	@EthernetAddress.setter
	def EthernetAddress(self, value):
		self._set_attribute('ethernetAddress', value)

	@property
	def PortAdministrativelyDown(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portAdministrativelyDown')
	@PortAdministrativelyDown.setter
	def PortAdministrativelyDown(self, value):
		self._set_attribute('portAdministrativelyDown', value)

	@property
	def PortConfig(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('portConfig')
	@PortConfig.setter
	def PortConfig(self, value):
		self._set_attribute('portConfig', value)

	@property
	def PortConfigMask(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('portConfigMask')
	@PortConfigMask.setter
	def PortConfigMask(self, value):
		self._set_attribute('portConfigMask', value)

	@property
	def PortNumber(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('portNumber')
	@PortNumber.setter
	def PortNumber(self, value):
		self._set_attribute('portNumber', value)

	def update(self, AdvertisedFeatures=None, DoNotSendPacketIn=None, DropAllPackets=None, DropForwardedPackets=None, EnableAdvertiseFeature=None, EnableEthernetAddress=None, EnablePortConfig=None, EnablePortModPortFeatures=None, EnablePortNumber=None, EthernetAddress=None, PortAdministrativelyDown=None, PortConfig=None, PortConfigMask=None, PortNumber=None):
		"""Updates a child instance of portModificationTriggerAttributes on the server.

		Args:
			AdvertisedFeatures (str): NOT DEFINED
			DoNotSendPacketIn (bool): NOT DEFINED
			DropAllPackets (bool): NOT DEFINED
			DropForwardedPackets (bool): NOT DEFINED
			EnableAdvertiseFeature (bool): NOT DEFINED
			EnableEthernetAddress (bool): NOT DEFINED
			EnablePortConfig (bool): NOT DEFINED
			EnablePortModPortFeatures (bool): NOT DEFINED
			EnablePortNumber (bool): NOT DEFINED
			EthernetAddress (str): NOT DEFINED
			PortAdministrativelyDown (bool): NOT DEFINED
			PortConfig (str): NOT DEFINED
			PortConfigMask (str): NOT DEFINED
			PortNumber (number): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



"""Sanity script that exercises all major points in the IxNetwork REST API
- sessions
- properties returning objects
- methods returning objects
- tracing
- authentication
- file transfer
- execs
- multivalues
- multivalue steps
"""
import sys
import os
import json
from ixnetwork_restpy.testplatform.testplatform import TestPlatform
from ixnetwork_restpy.errors import IxNetworkError
from ixnetwork_restpy.files import Files

sessions = None

try:
    test_platform = TestPlatform('127.0.0.1')
    test_platform.Trace = 'request_response'
    test_platform.Authenticate('admin', 'admin')
    print(test_platform)

    sessions = test_platform.Sessions.add()
    print(sessions)

    ixnetwork = sessions.Ixnetwork
    print(ixnetwork)

    views = ixnetwork.Statistics.View.find()
    print(views)

    try:
        ixnetwork.LoadConfig('c:/temp/ipv4_traffic.ixncfg')
        assert ('Type checking failed')
    except TypeError as e:
        print(e)
    ixnetwork.LoadConfig(Files('c:/users/anbalogh/downloads/ipv4_traffic.ixncfg', local_file=True))

    print(ixnetwork.Globals)
    print(ixnetwork.AvailableHardware)
    print(ixnetwork.Traffic)
    print(ixnetwork.Statistics)
    print(ixnetwork.ResourceManager)
    ixnetwork.NewConfig()
    
    assert(len(ixnetwork.Vport.find()) == 0)
    assert(len(ixnetwork.Topology.find()) == 0)
    assert(len(ixnetwork.AvailableHardware.Chassis.find()) == 0)
    assert(len(ixnetwork.Statistics.View.find()) == 0)
    assert(len(ixnetwork.Traffic.TrafficItem.find()) == 0)

    vport_name = 'Abstract Port 1'
    vports = ixnetwork.Vport.add(Name=vport_name, Type='pos')
    assert (vports.Type == 'pos')
    assert (vports.Name == vport_name)
    vports.Type = 'ethernet'
    assert (vports.Type == 'ethernet')
    vports.refresh()
    vports.add(Name='Abstract Port 2')
    vports.add(Name='Abstract Port 3')
    assert(len(vports) == 3)
    vports.remove()
    assert(len(vports) == 0)

    # create 2 ports
    vports.add().add()

    # create a raw traffic item
    traffic_item = ixnetwork.Traffic.TrafficItem.add(Name='Raw Traffic Item Test', TrafficType='raw', TrafficItemType='l2L3')
    protocols = vports.Protocols.find()
    assert (len(protocols) == 2)
    protocols.refresh()
    assert (len(protocols) == 2)
    endpoint_set = traffic_item.EndpointSet.add(Sources=protocols)
    assert (len(endpoint_set.Sources) == 2)
    mpls_protocol_template = ixnetwork.Traffic.ProtocolTemplate.find(StackTypeId='^mpls$')
    ethernet_stack = traffic_item.ConfigElement.find()[0].Stack.find(StackTypeId='^ethernet$')
    append_result = ethernet_stack.Append(mpls_protocol_template)

    # create a topology
    topology = ixnetwork.Topology.add(Name='Topology 1', Ports=vports)
    assert(len(topology) == 1)

    # create a device group
    device_group = topology.DeviceGroup.add(Name='Device 1', Multiplier='7')
    assert(len(device_group) == 1)
    device_group.Enabled.Alternate('False')
    assert (device_group.Enabled == 'Alt: False')
    
    # create and print ethernet information
    ethernet = device_group.Ethernet.add()
    assert(len(ethernet) == 1)

    # get multivalue information
    # # outputs format, count, possible patterns etc
    print(ethernet.Mac.Info)

    # multivalue steps
    steps = ethernet.Mac.Steps()
    for step in steps:
        print(step)
        step.Enabled = False
        step.refresh()
        assert (step.Enabled is False)
        
    # update multivalue on server immediately
    ethernet.Mac.Decrement(start_value='00:00:de:ad:be:ef', step_value='00:00:fa:ce:fa:ce')
    assert (ethernet.Mac == 'Dec: 00:00:de:ad:be:ef, 00:00:fa:ce:fa:ce')
    ethernet.Mac.Increment(start_value='00:00:fa:ce:fa:ce', step_value='00:00:de:ad:be:ef')
    assert (ethernet.Mac == 'Inc: 00:00:fa:ce:fa:ce, 00:00:de:ad:be:ef')
    ethernet.Mac.Random()
    assert (ethernet.Mac == 'Rand')
    ethernet.Mac.RandomRange()
    assert (ethernet.Mac.Pattern.startswith('Randr:'))
    ethernet.Mac.RandomMask()
    assert (ethernet.Mac.Pattern.startswith('Randb:'))
    ethernet.Mac.Distributed(algorithm='autoEven', mode='perPort', values=[('00:00:fa:ce:fa:ce', 60), ('0:00:de:ad:be:ef', 40)])
    assert (ethernet.Mac.Pattern.startswith('Dist:'))
    ethernet.Mac.ValueList(values=['00:00:fa:ce:fa:ce', '00:00:de:ad:be:ef'])
    assert (ethernet.Mac.Pattern.startswith('List:'))
    ethernet.Mac.Custom(start_value='00:00:fa:ce:fa:ce', step_value='00:00:de:ad:be:ef', increments=[('00:00:ab:ab:ab:ab', 6, [('00:00:01:01:01:01', 2, None)])])
    assert (ethernet.Mac.Pattern.startswith('Custom:'))
    print(ethernet.Mac.Values)
    
    ipv4 = ethernet.Ipv4.add(Name='Ipv4 1')
    print(ipv4)
    ipv4.Address.Increment(start_value='1.1.1.1', step_value='0.1.1.1')
    assert(ipv4.Address == 'Inc: 1.1.1.1, 0.1.1.1')
    
    bgp4 = ipv4.BgpIpv4Peer.add(Name='Bgp 1')
    bgp4.Md5Key.String('my-md5-key-{Dec: 1,1}')
    print(bgp4)

    # release all vports
    ixnetwork.Vport.find().ReleasePort()

    # add bgp6 in one line
    bgp6 = topology.DeviceGroup.add(Name='Device 2').Ethernet.add().Ipv6.add().BgpIpv6Peer.add()
    print(bgp6)

    # add one quick flow group per vport
    vports = ixnetwork.Vport.find()
    vports.AddQuickFlowGroups(1)
    
    # number of quick flow groups should equal the number of vports
    traffic_items = ixnetwork.Traffic.TrafficItem.find()
    high_level_streams = traffic_items.HighLevelStream.find()

    # errors = ixnetwork.Globals.AppErrors()[0].Error(Name='JSON Import Errors')
    # for instance in errors[0].Instance():
    # 	print(instance)

    # chassis = ixnetwork.AvailableHardware.add_Chassis(Hostname='10.36.24.55')
except IxNetworkError as e:
    print(e)

if sessions is not None:
    sessions.remove()





# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedInfo(Base):
	"""The LearnedInfo class encapsulates a system managed learnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'learnedInfo'

	def __init__(self, parent):
		super(LearnedInfo, self).__init__(parent)

	@property
	def ActorCollectingFlag(self):
		"""(read only) The learned Actor Collecting Flag status, either True of False. If True, the Collecting Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('actorCollectingFlag')

	@property
	def ActorDefaultedFlag(self):
		"""(read only) The learned Actor Defaulted Flag status, either True of False. If True, the Defaulted Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('actorDefaultedFlag')

	@property
	def ActorDistributingFlag(self):
		"""(read only) The learned Actor Distributing Flag status, either True of False. If True, the Distributing Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('actorDistributingFlag')

	@property
	def ActorExpiredFlag(self):
		"""(read only) The learned Actor Expired Flag status, either True of False. If True, the Expired Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('actorExpiredFlag')

	@property
	def ActorLacpActivity(self):
		"""(read only) The learned Actor LACP activity mode, either Passive or Active

		Returns:
			str(passive|active)
		"""
		return self._get_attribute('actorLacpActivity')

	@property
	def ActorLacpTimeout(self):
		"""(read only) The learned Actor LACPDU timeout mode, either Long or Short.

		Returns:
			str(long|short)
		"""
		return self._get_attribute('actorLacpTimeout')

	@property
	def ActorLinkAggregationStatus(self):
		"""(read only) The learned link aggregation status of the actor, either Aggregated or Not Aggregated.

		Returns:
			str(individual|aggregatable)
		"""
		return self._get_attribute('actorLinkAggregationStatus')

	@property
	def ActorOperationalKey(self):
		"""(read only) The learned Actor operation key, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('actorOperationalKey')

	@property
	def ActorPortNumber(self):
		"""(read only) The learned Actor port number in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('actorPortNumber')

	@property
	def ActorPortPriority(self):
		"""(read only) The learned Actor port priority, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('actorPortPriority')

	@property
	def ActorSyncFlag(self):
		"""(read only) The learned Actor synchronized status, either OUT_OF_SYNC/IN_SYNC.

		Returns:
			str(inSync|outOfSync)
		"""
		return self._get_attribute('actorSyncFlag')

	@property
	def ActorSystemId(self):
		"""(read only) The learned Actor system identifier, in 6 byte format.

		Returns:
			str
		"""
		return self._get_attribute('actorSystemId')

	@property
	def ActorSystemPriority(self):
		"""(read only) The learned Actor system priority, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('actorSystemPriority')

	@property
	def AdministrativeKey(self):
		"""(read only) This field controls the aggregation of ports of the same system with similar Actor Key.

		Returns:
			number
		"""
		return self._get_attribute('administrativeKey')

	@property
	def EnabledAggregation(self):
		"""(read only) The learned Actor aggregation status (whether the port is Individual or Aggregated).

		Returns:
			bool
		"""
		return self._get_attribute('enabledAggregation')

	@property
	def OtherLagMemberCount(self):
		"""(read only) The total number of ports,excluding the individual port that are a part of the LAG

		Returns:
			number
		"""
		return self._get_attribute('otherLagMemberCount')

	@property
	def OtherLagMemberDetails(self):
		"""(read only) The detailed information of the other member ports of the same LAG, visible in card:port format.

		Returns:
			str
		"""
		return self._get_attribute('otherLagMemberDetails')

	@property
	def PartnerCollectingFlag(self):
		"""(read only) The learned Partner Collecting Flag status, either True of False. If True, the Collecting Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('partnerCollectingFlag')

	@property
	def PartnerCollectorMaxDelay(self):
		"""(read only) The learned maximum Collection Delay for the partner, in microseconds.

		Returns:
			number
		"""
		return self._get_attribute('partnerCollectorMaxDelay')

	@property
	def PartnerDefaultedFlag(self):
		"""(read only) The learned Partner Defaulted Flag status, either True of False. If True, the Defaulted Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('partnerDefaultedFlag')

	@property
	def PartnerDistributingFlag(self):
		"""(read only) The learned Partner Distributing Flag status, either True of False. If True, the Distributing Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('partnerDistributingFlag')

	@property
	def PartnerExpiredFlag(self):
		"""(read only) The learned Partner Expired Flag status, either True of False. If True, the Expired Flag is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('partnerExpiredFlag')

	@property
	def PartnerLacpActivity(self):
		"""(read only) The learned Partner LACP activity mode, either Passive or Active

		Returns:
			str(passive|active)
		"""
		return self._get_attribute('partnerLacpActivity')

	@property
	def PartnerLacpTimeout(self):
		"""(read only) The learned Partner LACPDU timeout mode, either Long or Short.

		Returns:
			str(long|short)
		"""
		return self._get_attribute('partnerLacpTimeout')

	@property
	def PartnerLinkAggregationStatus(self):
		"""(read only) The learned link aggregation status of the partner, either Aggregated or Not Aggregated.

		Returns:
			str(individual|aggregatable)
		"""
		return self._get_attribute('partnerLinkAggregationStatus')

	@property
	def PartnerOperationalKey(self):
		"""(read only) The learned Partner operation key, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('partnerOperationalKey')

	@property
	def PartnerPortNumber(self):
		"""(read only) The learned Partner port number in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('partnerPortNumber')

	@property
	def PartnerPortPriority(self):
		"""(read only) The learned Partner port priority, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('partnerPortPriority')

	@property
	def PartnerSyncFlag(self):
		"""(read only) The learned Partner synchronized status, either OUT_OF_SYNC/IN_SYNC.

		Returns:
			str(inSync|outOfSync)
		"""
		return self._get_attribute('partnerSyncFlag')

	@property
	def PartnerSystemId(self):
		"""(read only) The learned Partner system identifier, in 6 byte format.

		Returns:
			str
		"""
		return self._get_attribute('partnerSystemId')

	@property
	def PartnerSystemPriority(self):
		"""(read only) The learned Partner system priority, in hexadecimal format.

		Returns:
			number
		"""
		return self._get_attribute('partnerSystemPriority')

	def find(self, ActorCollectingFlag=None, ActorDefaultedFlag=None, ActorDistributingFlag=None, ActorExpiredFlag=None, ActorLacpActivity=None, ActorLacpTimeout=None, ActorLinkAggregationStatus=None, ActorOperationalKey=None, ActorPortNumber=None, ActorPortPriority=None, ActorSyncFlag=None, ActorSystemId=None, ActorSystemPriority=None, AdministrativeKey=None, EnabledAggregation=None, OtherLagMemberCount=None, OtherLagMemberDetails=None, PartnerCollectingFlag=None, PartnerCollectorMaxDelay=None, PartnerDefaultedFlag=None, PartnerDistributingFlag=None, PartnerExpiredFlag=None, PartnerLacpActivity=None, PartnerLacpTimeout=None, PartnerLinkAggregationStatus=None, PartnerOperationalKey=None, PartnerPortNumber=None, PartnerPortPriority=None, PartnerSyncFlag=None, PartnerSystemId=None, PartnerSystemPriority=None):
		"""Finds and retrieves learnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve learnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all learnedInfo data from the server.

		Args:
			ActorCollectingFlag (bool): (read only) The learned Actor Collecting Flag status, either True of False. If True, the Collecting Flag is enabled.
			ActorDefaultedFlag (bool): (read only) The learned Actor Defaulted Flag status, either True of False. If True, the Defaulted Flag is enabled.
			ActorDistributingFlag (bool): (read only) The learned Actor Distributing Flag status, either True of False. If True, the Distributing Flag is enabled.
			ActorExpiredFlag (bool): (read only) The learned Actor Expired Flag status, either True of False. If True, the Expired Flag is enabled.
			ActorLacpActivity (str(passive|active)): (read only) The learned Actor LACP activity mode, either Passive or Active
			ActorLacpTimeout (str(long|short)): (read only) The learned Actor LACPDU timeout mode, either Long or Short.
			ActorLinkAggregationStatus (str(individual|aggregatable)): (read only) The learned link aggregation status of the actor, either Aggregated or Not Aggregated.
			ActorOperationalKey (number): (read only) The learned Actor operation key, in hexadecimal format.
			ActorPortNumber (number): (read only) The learned Actor port number in hexadecimal format.
			ActorPortPriority (number): (read only) The learned Actor port priority, in hexadecimal format.
			ActorSyncFlag (str(inSync|outOfSync)): (read only) The learned Actor synchronized status, either OUT_OF_SYNC/IN_SYNC.
			ActorSystemId (str): (read only) The learned Actor system identifier, in 6 byte format.
			ActorSystemPriority (number): (read only) The learned Actor system priority, in hexadecimal format.
			AdministrativeKey (number): (read only) This field controls the aggregation of ports of the same system with similar Actor Key.
			EnabledAggregation (bool): (read only) The learned Actor aggregation status (whether the port is Individual or Aggregated).
			OtherLagMemberCount (number): (read only) The total number of ports,excluding the individual port that are a part of the LAG
			OtherLagMemberDetails (str): (read only) The detailed information of the other member ports of the same LAG, visible in card:port format.
			PartnerCollectingFlag (bool): (read only) The learned Partner Collecting Flag status, either True of False. If True, the Collecting Flag is enabled.
			PartnerCollectorMaxDelay (number): (read only) The learned maximum Collection Delay for the partner, in microseconds.
			PartnerDefaultedFlag (bool): (read only) The learned Partner Defaulted Flag status, either True of False. If True, the Defaulted Flag is enabled.
			PartnerDistributingFlag (bool): (read only) The learned Partner Distributing Flag status, either True of False. If True, the Distributing Flag is enabled.
			PartnerExpiredFlag (bool): (read only) The learned Partner Expired Flag status, either True of False. If True, the Expired Flag is enabled.
			PartnerLacpActivity (str(passive|active)): (read only) The learned Partner LACP activity mode, either Passive or Active
			PartnerLacpTimeout (str(long|short)): (read only) The learned Partner LACPDU timeout mode, either Long or Short.
			PartnerLinkAggregationStatus (str(individual|aggregatable)): (read only) The learned link aggregation status of the partner, either Aggregated or Not Aggregated.
			PartnerOperationalKey (number): (read only) The learned Partner operation key, in hexadecimal format.
			PartnerPortNumber (number): (read only) The learned Partner port number in hexadecimal format.
			PartnerPortPriority (number): (read only) The learned Partner port priority, in hexadecimal format.
			PartnerSyncFlag (str(inSync|outOfSync)): (read only) The learned Partner synchronized status, either OUT_OF_SYNC/IN_SYNC.
			PartnerSystemId (str): (read only) The learned Partner system identifier, in 6 byte format.
			PartnerSystemPriority (number): (read only) The learned Partner system priority, in hexadecimal format.

		Returns:
			self: This instance with matching learnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of learnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the learnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Router(Base):
	"""The Router class encapsulates a user managed router node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Router property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'router'

	def __init__(self, parent):
		super(Router, self).__init__(parent)

	@property
	def AdvFecRange(self):
		"""An instance of the AdvFecRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.advfecrange.advfecrange.AdvFecRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.advfecrange.advfecrange import AdvFecRange
		return AdvFecRange(self)

	@property
	def IncludeIpFecRange(self):
		"""An instance of the IncludeIpFecRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.includeipfecrange.includeipfecrange.IncludeIpFecRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.includeipfecrange.includeipfecrange import IncludeIpFecRange
		return IncludeIpFecRange(self)

	@property
	def Interface(self):
		"""An instance of the Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.interface.interface.Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.interface.interface import Interface
		return Interface(self)

	@property
	def L2Interface(self):
		"""An instance of the L2Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2interface.L2Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.l2interface.l2interface import L2Interface
		return L2Interface(self)

	@property
	def LearnedBgpAdVplsLabels(self):
		"""An instance of the LearnedBgpAdVplsLabels class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.learnedbgpadvplslabels.learnedbgpadvplslabels.LearnedBgpAdVplsLabels)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.learnedbgpadvplslabels.learnedbgpadvplslabels import LearnedBgpAdVplsLabels
		return LearnedBgpAdVplsLabels(self)

	@property
	def MulticastLeafRange(self):
		"""An instance of the MulticastLeafRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.multicastleafrange.MulticastLeafRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.multicastleafrange import MulticastLeafRange
		return MulticastLeafRange(self)

	@property
	def MulticastRootRange(self):
		"""An instance of the MulticastRootRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastrootrange.multicastrootrange.MulticastRootRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastrootrange.multicastrootrange import MulticastRootRange
		return MulticastRootRange(self)

	@property
	def ReqFecRange(self):
		"""An instance of the ReqFecRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.reqfecrange.reqfecrange.ReqFecRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.reqfecrange.reqfecrange import ReqFecRange
		return ReqFecRange(self)

	@property
	def EnableBfdMplsLearnedLsp(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableBfdMplsLearnedLsp')
	@EnableBfdMplsLearnedLsp.setter
	def EnableBfdMplsLearnedLsp(self, value):
		self._set_attribute('enableBfdMplsLearnedLsp', value)

	@property
	def EnableFilterFec(self):
		"""Enables Filter FEC, which allows the user to control which received FEC ranges will be stored in the state machine.

		Returns:
			bool
		"""
		return self._get_attribute('enableFilterFec')
	@EnableFilterFec.setter
	def EnableFilterFec(self, value):
		self._set_attribute('enableFilterFec', value)

	@property
	def EnableGracefulRestart(self):
		"""If enabled, LDP Graceful Restart is enabled on this Ixia-emulated LDP Router.

		Returns:
			bool
		"""
		return self._get_attribute('enableGracefulRestart')
	@EnableGracefulRestart.setter
	def EnableGracefulRestart(self, value):
		self._set_attribute('enableGracefulRestart', value)

	@property
	def EnableLspPingLearnedLsp(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLspPingLearnedLsp')
	@EnableLspPingLearnedLsp.setter
	def EnableLspPingLearnedLsp(self, value):
		self._set_attribute('enableLspPingLearnedLsp', value)

	@property
	def EnableOverrideRbit(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableOverrideRbit')
	@EnableOverrideRbit.setter
	def EnableOverrideRbit(self, value):
		self._set_attribute('enableOverrideRbit', value)

	@property
	def EnableP2mpCapabilty(self):
		"""If true, enables P2MP capability.

		Returns:
			bool
		"""
		return self._get_attribute('enableP2mpCapabilty')
	@EnableP2mpCapabilty.setter
	def EnableP2mpCapabilty(self, value):
		self._set_attribute('enableP2mpCapabilty', value)

	@property
	def EnablePduRateControl(self):
		"""Enables the PDU Rate Control feature.

		Returns:
			bool
		"""
		return self._get_attribute('enablePduRateControl')
	@EnablePduRateControl.setter
	def EnablePduRateControl(self, value):
		self._set_attribute('enablePduRateControl', value)

	@property
	def EnableVcFecs(self):
		"""Enables the use of Layer 2 Virtual Circuit FECs.

		Returns:
			bool
		"""
		return self._get_attribute('enableVcFecs')
	@EnableVcFecs.setter
	def EnableVcFecs(self, value):
		self._set_attribute('enableVcFecs', value)

	@property
	def EnableVcGroupMatch(self):
		"""If enabled, the VC Group ID must be matched in addition to the VC ID, VC Type, and Peer for the PseudoWire to be considered Up (Up status).

		Returns:
			bool
		"""
		return self._get_attribute('enableVcGroupMatch')
	@EnableVcGroupMatch.setter
	def EnableVcGroupMatch(self, value):
		self._set_attribute('enableVcGroupMatch', value)

	@property
	def Enabled(self):
		"""Enables or disables the simulated router.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def InterPduGap(self):
		"""The user-specified gap time between PDUs, in milliseconds (ms).

		Returns:
			number
		"""
		return self._get_attribute('interPduGap')
	@InterPduGap.setter
	def InterPduGap(self, value):
		self._set_attribute('interPduGap', value)

	@property
	def IsBgpAdVplsLearnedInfoRefreshed(self):
		"""Refreshes the AD VPLS Learned Info.

		Returns:
			bool
		"""
		return self._get_attribute('isBgpAdVplsLearnedInfoRefreshed')

	@property
	def ReconnectTime(self):
		"""This Fault Tolerant (FT) Reconnect Timer value is advertised in the FT Session TLV in the Initialization message sent by a neighbor LSR. It is a request sent by an LSR to its neighbor(s) in the event that the receiving neighbor detects that the LDP session has failed, the receiver should maintain MPLS forwarding state and wait for the sender to perform a restart of the control plane and LDP protocol. If the value = 0, the sender is indicating that it will not preserve its MPLS forwarding state across the restart.

		Returns:
			number
		"""
		return self._get_attribute('reconnectTime')
	@ReconnectTime.setter
	def ReconnectTime(self, value):
		self._set_attribute('reconnectTime', value)

	@property
	def RecoveryTime(self):
		"""The restarting LSR is advertising the amount of time that it will retain its MPLS forwarding state. This time period begins when it sends the restart Initialization message, with the FT session TLV, to the neighbor LSRs (to re-establish the LDP session). This timer allows the neighbors some time to resync the LSPs in an orderly manner. If the value = 0, it means that the restarting LSR was not able to preserve the MPLS forwarding state.

		Returns:
			number
		"""
		return self._get_attribute('recoveryTime')
	@RecoveryTime.setter
	def RecoveryTime(self, value):
		self._set_attribute('recoveryTime', value)

	@property
	def RouterId(self):
		"""The ID of the simulated router, expressed as an IP address.

		Returns:
			str
		"""
		return self._get_attribute('routerId')
	@RouterId.setter
	def RouterId(self, value):
		self._set_attribute('routerId', value)

	@property
	def TrafficGroupId(self):
		"""The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)
		"""
		return self._get_attribute('trafficGroupId')
	@TrafficGroupId.setter
	def TrafficGroupId(self, value):
		self._set_attribute('trafficGroupId', value)

	@property
	def TransportAddress(self):
		"""The string interface description for the transport address.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)
		"""
		return self._get_attribute('transportAddress')
	@TransportAddress.setter
	def TransportAddress(self, value):
		self._set_attribute('transportAddress', value)

	@property
	def UseTransportAddress(self):
		"""The boolean value for the transport address.

		Returns:
			bool
		"""
		return self._get_attribute('useTransportAddress')
	@UseTransportAddress.setter
	def UseTransportAddress(self, value):
		self._set_attribute('useTransportAddress', value)

	def update(self, EnableBfdMplsLearnedLsp=None, EnableFilterFec=None, EnableGracefulRestart=None, EnableLspPingLearnedLsp=None, EnableOverrideRbit=None, EnableP2mpCapabilty=None, EnablePduRateControl=None, EnableVcFecs=None, EnableVcGroupMatch=None, Enabled=None, InterPduGap=None, ReconnectTime=None, RecoveryTime=None, RouterId=None, TrafficGroupId=None, TransportAddress=None, UseTransportAddress=None):
		"""Updates a child instance of router on the server.

		Args:
			EnableBfdMplsLearnedLsp (bool): NOT DEFINED
			EnableFilterFec (bool): Enables Filter FEC, which allows the user to control which received FEC ranges will be stored in the state machine.
			EnableGracefulRestart (bool): If enabled, LDP Graceful Restart is enabled on this Ixia-emulated LDP Router.
			EnableLspPingLearnedLsp (bool): NOT DEFINED
			EnableOverrideRbit (bool): NOT DEFINED
			EnableP2mpCapabilty (bool): If true, enables P2MP capability.
			EnablePduRateControl (bool): Enables the PDU Rate Control feature.
			EnableVcFecs (bool): Enables the use of Layer 2 Virtual Circuit FECs.
			EnableVcGroupMatch (bool): If enabled, the VC Group ID must be matched in addition to the VC ID, VC Type, and Peer for the PseudoWire to be considered Up (Up status).
			Enabled (bool): Enables or disables the simulated router.
			InterPduGap (number): The user-specified gap time between PDUs, in milliseconds (ms).
			ReconnectTime (number): This Fault Tolerant (FT) Reconnect Timer value is advertised in the FT Session TLV in the Initialization message sent by a neighbor LSR. It is a request sent by an LSR to its neighbor(s) in the event that the receiving neighbor detects that the LDP session has failed, the receiver should maintain MPLS forwarding state and wait for the sender to perform a restart of the control plane and LDP protocol. If the value = 0, the sender is indicating that it will not preserve its MPLS forwarding state across the restart.
			RecoveryTime (number): The restarting LSR is advertising the amount of time that it will retain its MPLS forwarding state. This time period begins when it sends the restart Initialization message, with the FT session TLV, to the neighbor LSRs (to re-establish the LDP session). This timer allows the neighbors some time to resync the LSPs in an orderly manner. If the value = 0, it means that the restarting LSR was not able to preserve the MPLS forwarding state.
			RouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TransportAddress (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The string interface description for the transport address.
			UseTransportAddress (bool): The boolean value for the transport address.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, EnableBfdMplsLearnedLsp=None, EnableFilterFec=None, EnableGracefulRestart=None, EnableLspPingLearnedLsp=None, EnableOverrideRbit=None, EnableP2mpCapabilty=None, EnablePduRateControl=None, EnableVcFecs=None, EnableVcGroupMatch=None, Enabled=None, InterPduGap=None, ReconnectTime=None, RecoveryTime=None, RouterId=None, TrafficGroupId=None, TransportAddress=None, UseTransportAddress=None):
		"""Adds a new router node on the server and retrieves it in this instance.

		Args:
			EnableBfdMplsLearnedLsp (bool): NOT DEFINED
			EnableFilterFec (bool): Enables Filter FEC, which allows the user to control which received FEC ranges will be stored in the state machine.
			EnableGracefulRestart (bool): If enabled, LDP Graceful Restart is enabled on this Ixia-emulated LDP Router.
			EnableLspPingLearnedLsp (bool): NOT DEFINED
			EnableOverrideRbit (bool): NOT DEFINED
			EnableP2mpCapabilty (bool): If true, enables P2MP capability.
			EnablePduRateControl (bool): Enables the PDU Rate Control feature.
			EnableVcFecs (bool): Enables the use of Layer 2 Virtual Circuit FECs.
			EnableVcGroupMatch (bool): If enabled, the VC Group ID must be matched in addition to the VC ID, VC Type, and Peer for the PseudoWire to be considered Up (Up status).
			Enabled (bool): Enables or disables the simulated router.
			InterPduGap (number): The user-specified gap time between PDUs, in milliseconds (ms).
			ReconnectTime (number): This Fault Tolerant (FT) Reconnect Timer value is advertised in the FT Session TLV in the Initialization message sent by a neighbor LSR. It is a request sent by an LSR to its neighbor(s) in the event that the receiving neighbor detects that the LDP session has failed, the receiver should maintain MPLS forwarding state and wait for the sender to perform a restart of the control plane and LDP protocol. If the value = 0, the sender is indicating that it will not preserve its MPLS forwarding state across the restart.
			RecoveryTime (number): The restarting LSR is advertising the amount of time that it will retain its MPLS forwarding state. This time period begins when it sends the restart Initialization message, with the FT session TLV, to the neighbor LSRs (to re-establish the LDP session). This timer allows the neighbors some time to resync the LSPs in an orderly manner. If the value = 0, it means that the restarting LSR was not able to preserve the MPLS forwarding state.
			RouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TransportAddress (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The string interface description for the transport address.
			UseTransportAddress (bool): The boolean value for the transport address.

		Returns:
			self: This instance with all currently retrieved router data using find and the newly added router data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the router data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, EnableBfdMplsLearnedLsp=None, EnableFilterFec=None, EnableGracefulRestart=None, EnableLspPingLearnedLsp=None, EnableOverrideRbit=None, EnableP2mpCapabilty=None, EnablePduRateControl=None, EnableVcFecs=None, EnableVcGroupMatch=None, Enabled=None, InterPduGap=None, IsBgpAdVplsLearnedInfoRefreshed=None, ReconnectTime=None, RecoveryTime=None, RouterId=None, TrafficGroupId=None, TransportAddress=None, UseTransportAddress=None):
		"""Finds and retrieves router data from the server.

		All named parameters support regex and can be used to selectively retrieve router data from the server.
		By default the find method takes no parameters and will retrieve all router data from the server.

		Args:
			EnableBfdMplsLearnedLsp (bool): NOT DEFINED
			EnableFilterFec (bool): Enables Filter FEC, which allows the user to control which received FEC ranges will be stored in the state machine.
			EnableGracefulRestart (bool): If enabled, LDP Graceful Restart is enabled on this Ixia-emulated LDP Router.
			EnableLspPingLearnedLsp (bool): NOT DEFINED
			EnableOverrideRbit (bool): NOT DEFINED
			EnableP2mpCapabilty (bool): If true, enables P2MP capability.
			EnablePduRateControl (bool): Enables the PDU Rate Control feature.
			EnableVcFecs (bool): Enables the use of Layer 2 Virtual Circuit FECs.
			EnableVcGroupMatch (bool): If enabled, the VC Group ID must be matched in addition to the VC ID, VC Type, and Peer for the PseudoWire to be considered Up (Up status).
			Enabled (bool): Enables or disables the simulated router.
			InterPduGap (number): The user-specified gap time between PDUs, in milliseconds (ms).
			IsBgpAdVplsLearnedInfoRefreshed (bool): Refreshes the AD VPLS Learned Info.
			ReconnectTime (number): This Fault Tolerant (FT) Reconnect Timer value is advertised in the FT Session TLV in the Initialization message sent by a neighbor LSR. It is a request sent by an LSR to its neighbor(s) in the event that the receiving neighbor detects that the LDP session has failed, the receiver should maintain MPLS forwarding state and wait for the sender to perform a restart of the control plane and LDP protocol. If the value = 0, the sender is indicating that it will not preserve its MPLS forwarding state across the restart.
			RecoveryTime (number): The restarting LSR is advertising the amount of time that it will retain its MPLS forwarding state. This time period begins when it sends the restart Initialization message, with the FT session TLV, to the neighbor LSRs (to re-establish the LDP session). This timer allows the neighbors some time to resync the LSPs in an orderly manner. If the value = 0, it means that the restarting LSR was not able to preserve the MPLS forwarding state.
			RouterId (str): The ID of the simulated router, expressed as an IP address.
			TrafficGroupId (str(None|/api/v1/sessions/1/ixnetwork/traffic?deepchild=trafficGroup)): The name of the group to which this port is assigned, for the purpose of creating traffic streams among source/destination members of the group.
			TransportAddress (str(None|/api/v1/sessions/1/ixnetwork/vport?deepchild=interface)): The string interface description for the transport address.
			UseTransportAddress (bool): The boolean value for the transport address.

		Returns:
			self: This instance with matching router data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of router data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the router data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def RefreshBgpAdVplsLearnedInfo(self):
		"""Executes the refreshBgpAdVplsLearnedInfo operation on the server.

		If enabled, it refreshes BGP advanced LSP learned information.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshBgpAdVplsLearnedInfo', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ipv6MulticastVpn(Base):
	"""The Ipv6MulticastVpn class encapsulates a system managed ipv6MulticastVpn node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ipv6MulticastVpn property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'ipv6MulticastVpn'

	def __init__(self, parent):
		super(Ipv6MulticastVpn, self).__init__(parent)

	@property
	def CMcastRouteType(self):
		"""The c-multicast route type.

		Returns:
			str
		"""
		return self._get_attribute('cMcastRouteType')

	@property
	def GroupAddress(self):
		"""The IPv6 Multicast group address in the range of group addresses included in this Register message.

		Returns:
			str
		"""
		return self._get_attribute('groupAddress')

	@property
	def Neighbor(self):
		"""The neighbor address.

		Returns:
			str
		"""
		return self._get_attribute('neighbor')

	@property
	def OriginatingRouter(self):
		"""The originating router address.

		Returns:
			str
		"""
		return self._get_attribute('originatingRouter')

	@property
	def RouteDistinguisher(self):
		"""The route distinguisher for the route, for use with IPv6 multicast VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeDistinguisher')

	@property
	def RouteKeyGroupAddress(self):
		"""The key group address of the route.

		Returns:
			str
		"""
		return self._get_attribute('routeKeyGroupAddress')

	@property
	def RouteKeyOriginatingRouter(self):
		"""The key originating address of the router.

		Returns:
			str
		"""
		return self._get_attribute('routeKeyOriginatingRouter')

	@property
	def RouteKeyRouteDistinguisher(self):
		"""The key route distinguisher for the route, for use with IPv6 multicast VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeKeyRouteDistinguisher')

	@property
	def RouteKeyRsvpP2mpExtendedTunnelId(self):
		"""The key rsvp p2mp extended tunnel id for the route, for use with IPv6 multicast VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeKeyRsvpP2mpExtendedTunnelId')

	@property
	def RouteKeyRsvpP2mpId(self):
		"""The key rsvp p2mp id for the route, for use with IPv6 multicast VPN address types.

		Returns:
			number
		"""
		return self._get_attribute('routeKeyRsvpP2mpId')

	@property
	def RouteKeyRsvpP2mpTunnelId(self):
		"""The key rsvp p2mp tunnel id for the route, for use with IPv6 multicast VPN address types.

		Returns:
			number
		"""
		return self._get_attribute('routeKeyRsvpP2mpTunnelId')

	@property
	def RouteKeySourceAddress(self):
		"""The key source address for the route, for use with IPv6 multicast VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeKeySourceAddress')

	@property
	def RouteKeyTunnelType(self):
		"""The key tunnel type for the route, for use with IPv6 multicast VPN address types.

		Returns:
			str
		"""
		return self._get_attribute('routeKeyTunnelType')

	@property
	def RouteKeyUpstreamLabel(self):
		"""The key upstream label for the route, for use with IPv6 multicast VPN address types.

		Returns:
			number
		"""
		return self._get_attribute('routeKeyUpstreamLabel')

	@property
	def RouteType(self):
		"""The route type.

		Returns:
			str
		"""
		return self._get_attribute('routeType')

	@property
	def RsvpP2mpExtendedTunnelId(self):
		"""The rsvp p2mp extended tunnel id.

		Returns:
			str
		"""
		return self._get_attribute('rsvpP2mpExtendedTunnelId')

	@property
	def RsvpP2mpId(self):
		"""The rsvp p2mp id.

		Returns:
			number
		"""
		return self._get_attribute('rsvpP2mpId')

	@property
	def RsvpP2mpTunnelId(self):
		"""The rsvp p2mp tunnel id.

		Returns:
			number
		"""
		return self._get_attribute('rsvpP2mpTunnelId')

	@property
	def SourceAddress(self):
		"""The source address.

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress')

	@property
	def SourceAs(self):
		"""The source AS number.

		Returns:
			number
		"""
		return self._get_attribute('sourceAs')

	@property
	def TunnelType(self):
		"""The tunnel type.

		Returns:
			str
		"""
		return self._get_attribute('tunnelType')

	@property
	def UpstreamLabel(self):
		"""The upstream label.

		Returns:
			number
		"""
		return self._get_attribute('upstreamLabel')

	def find(self, CMcastRouteType=None, GroupAddress=None, Neighbor=None, OriginatingRouter=None, RouteDistinguisher=None, RouteKeyGroupAddress=None, RouteKeyOriginatingRouter=None, RouteKeyRouteDistinguisher=None, RouteKeyRsvpP2mpExtendedTunnelId=None, RouteKeyRsvpP2mpId=None, RouteKeyRsvpP2mpTunnelId=None, RouteKeySourceAddress=None, RouteKeyTunnelType=None, RouteKeyUpstreamLabel=None, RouteType=None, RsvpP2mpExtendedTunnelId=None, RsvpP2mpId=None, RsvpP2mpTunnelId=None, SourceAddress=None, SourceAs=None, TunnelType=None, UpstreamLabel=None):
		"""Finds and retrieves ipv6MulticastVpn data from the server.

		All named parameters support regex and can be used to selectively retrieve ipv6MulticastVpn data from the server.
		By default the find method takes no parameters and will retrieve all ipv6MulticastVpn data from the server.

		Args:
			CMcastRouteType (str): The c-multicast route type.
			GroupAddress (str): The IPv6 Multicast group address in the range of group addresses included in this Register message.
			Neighbor (str): The neighbor address.
			OriginatingRouter (str): The originating router address.
			RouteDistinguisher (str): The route distinguisher for the route, for use with IPv6 multicast VPN address types.
			RouteKeyGroupAddress (str): The key group address of the route.
			RouteKeyOriginatingRouter (str): The key originating address of the router.
			RouteKeyRouteDistinguisher (str): The key route distinguisher for the route, for use with IPv6 multicast VPN address types.
			RouteKeyRsvpP2mpExtendedTunnelId (str): The key rsvp p2mp extended tunnel id for the route, for use with IPv6 multicast VPN address types.
			RouteKeyRsvpP2mpId (number): The key rsvp p2mp id for the route, for use with IPv6 multicast VPN address types.
			RouteKeyRsvpP2mpTunnelId (number): The key rsvp p2mp tunnel id for the route, for use with IPv6 multicast VPN address types.
			RouteKeySourceAddress (str): The key source address for the route, for use with IPv6 multicast VPN address types.
			RouteKeyTunnelType (str): The key tunnel type for the route, for use with IPv6 multicast VPN address types.
			RouteKeyUpstreamLabel (number): The key upstream label for the route, for use with IPv6 multicast VPN address types.
			RouteType (str): The route type.
			RsvpP2mpExtendedTunnelId (str): The rsvp p2mp extended tunnel id.
			RsvpP2mpId (number): The rsvp p2mp id.
			RsvpP2mpTunnelId (number): The rsvp p2mp tunnel id.
			SourceAddress (str): The source address.
			SourceAs (number): The source AS number.
			TunnelType (str): The tunnel type.
			UpstreamLabel (number): The upstream label.

		Returns:
			self: This instance with matching ipv6MulticastVpn data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of ipv6MulticastVpn data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the ipv6MulticastVpn data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class RouteDistinguisher(Base):
	"""The RouteDistinguisher class encapsulates a required routeDistinguisher node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the RouteDistinguisher property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'routeDistinguisher'

	def __init__(self, parent):
		super(RouteDistinguisher, self).__init__(parent)

	@property
	def AsNumber(self):
		"""If the type was set to as or asNumber2, this is the AS number in the Administrator subfield of the Value field of the MVPN Route Distinguisher (RD). It is the Global part of the RD. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('asNumber')
	@AsNumber.setter
	def AsNumber(self, value):
		self._set_attribute('asNumber', value)

	@property
	def AsNumberStep(self):
		"""The increment step for for the AS.

		Returns:
			number
		"""
		return self._get_attribute('asNumberStep')
	@AsNumberStep.setter
	def AsNumberStep(self, value):
		self._set_attribute('asNumberStep', value)

	@property
	def AssignedNumber(self):
		"""The Assigned Number sub-field of the Value field of the MVPN Route Distinguisher. It is a number from a numbering space, which the enterprise administers, for a given IP address or ASN space. It is the Local part of the RD. (default = 0)

		Returns:
			number
		"""
		return self._get_attribute('assignedNumber')
	@AssignedNumber.setter
	def AssignedNumber(self, value):
		self._set_attribute('assignedNumber', value)

	@property
	def AssignedNumberStep(self):
		"""The increment step for for the assigned number.

		Returns:
			number
		"""
		return self._get_attribute('assignedNumberStep')
	@AssignedNumberStep.setter
	def AssignedNumberStep(self, value):
		self._set_attribute('assignedNumberStep', value)

	@property
	def IpAddress(self):
		"""If the type was set to ip, this is the 4-byte IP address in the Administrator subfield of the Value field of the MVPN Route Distinguisher (RD). It is the Global part of the RD. (default = 0.0.0.0)

		Returns:
			str
		"""
		return self._get_attribute('ipAddress')
	@IpAddress.setter
	def IpAddress(self, value):
		self._set_attribute('ipAddress', value)

	@property
	def IpAddressStep(self):
		"""The increment step for for the IP address.

		Returns:
			str
		"""
		return self._get_attribute('ipAddressStep')
	@IpAddressStep.setter
	def IpAddressStep(self, value):
		self._set_attribute('ipAddressStep', value)

	@property
	def Type(self):
		"""Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.

		Returns:
			str(as|ip|asNumber2)
		"""
		return self._get_attribute('type')
	@Type.setter
	def Type(self, value):
		self._set_attribute('type', value)

	def update(self, AsNumber=None, AsNumberStep=None, AssignedNumber=None, AssignedNumberStep=None, IpAddress=None, IpAddressStep=None, Type=None):
		"""Updates a child instance of routeDistinguisher on the server.

		Args:
			AsNumber (number): If the type was set to as or asNumber2, this is the AS number in the Administrator subfield of the Value field of the MVPN Route Distinguisher (RD). It is the Global part of the RD. (default = 0)
			AsNumberStep (number): The increment step for for the AS.
			AssignedNumber (number): The Assigned Number sub-field of the Value field of the MVPN Route Distinguisher. It is a number from a numbering space, which the enterprise administers, for a given IP address or ASN space. It is the Local part of the RD. (default = 0)
			AssignedNumberStep (number): The increment step for for the assigned number.
			IpAddress (str): If the type was set to ip, this is the 4-byte IP address in the Administrator subfield of the Value field of the MVPN Route Distinguisher (RD). It is the Global part of the RD. (default = 0.0.0.0)
			IpAddressStep (str): The increment step for for the IP address.
			Type (str(as|ip|asNumber2)): Indicates the type of administrator field used in route distinguisher that will be included in the route announcements.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MeterConfigStatsLearnedInformation(Base):
	"""The MeterConfigStatsLearnedInformation class encapsulates a system managed meterConfigStatsLearnedInformation node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MeterConfigStatsLearnedInformation property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'meterConfigStatsLearnedInformation'

	def __init__(self, parent):
		super(MeterConfigStatsLearnedInformation, self).__init__(parent)

	@property
	def MeterConfigStatsBandLearnedInformation(self):
		"""An instance of the MeterConfigStatsBandLearnedInformation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.meterconfigstatsbandlearnedinformation.MeterConfigStatsBandLearnedInformation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.meterconfigstatsbandlearnedinformation import MeterConfigStatsBandLearnedInformation
		return MeterConfigStatsBandLearnedInformation(self)

	@property
	def DataPathId(self):
		"""The Data Path identifier of the OpenFlow Controller.

		Returns:
			number
		"""
		return self._get_attribute('dataPathId')

	@property
	def DataPathIdAsHex(self):
		"""The Data Path identifier of the OpenFlow Controller in hexadecimal format.

		Returns:
			str
		"""
		return self._get_attribute('dataPathIdAsHex')

	@property
	def ErrorCode(self):
		"""The error code of the received error.

		Returns:
			str
		"""
		return self._get_attribute('errorCode')

	@property
	def ErrorType(self):
		"""The type of the error received.

		Returns:
			str
		"""
		return self._get_attribute('errorType')

	@property
	def Flags(self):
		"""Select the meter configuration flags from the list.

		Returns:
			str
		"""
		return self._get_attribute('flags')

	@property
	def LastErrorCode(self):
		"""The Last error code of the received error.

		Returns:
			str
		"""
		return self._get_attribute('lastErrorCode')

	@property
	def LastErrorType(self):
		"""The type of the Last error received.

		Returns:
			str
		"""
		return self._get_attribute('lastErrorType')

	@property
	def Latency(self):
		"""The latency measurement for the OpenFlow channel in microseconds.

		Returns:
			number
		"""
		return self._get_attribute('latency')

	@property
	def LocalIp(self):
		"""Indicates the local IP of the Controller.

		Returns:
			str
		"""
		return self._get_attribute('localIp')

	@property
	def MeterId(self):
		"""Specifies Meter ID

		Returns:
			number
		"""
		return self._get_attribute('meterId')

	@property
	def NegotiatedVersion(self):
		"""Version of the protocol that has been negotiated between OpenFLow Controller and Switch.

		Returns:
			str
		"""
		return self._get_attribute('negotiatedVersion')

	@property
	def NumberOfBands(self):
		"""Specify the number of Bands for this controller configuration. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('numberOfBands')

	@property
	def RemoteIp(self):
		"""The Remote IP address of the selected interface.

		Returns:
			str
		"""
		return self._get_attribute('remoteIp')

	@property
	def ReplyState(self):
		"""The state of reply for the Open Flow channel.

		Returns:
			str
		"""
		return self._get_attribute('replyState')

	def find(self, DataPathId=None, DataPathIdAsHex=None, ErrorCode=None, ErrorType=None, Flags=None, LastErrorCode=None, LastErrorType=None, Latency=None, LocalIp=None, MeterId=None, NegotiatedVersion=None, NumberOfBands=None, RemoteIp=None, ReplyState=None):
		"""Finds and retrieves meterConfigStatsLearnedInformation data from the server.

		All named parameters support regex and can be used to selectively retrieve meterConfigStatsLearnedInformation data from the server.
		By default the find method takes no parameters and will retrieve all meterConfigStatsLearnedInformation data from the server.

		Args:
			DataPathId (number): The Data Path identifier of the OpenFlow Controller.
			DataPathIdAsHex (str): The Data Path identifier of the OpenFlow Controller in hexadecimal format.
			ErrorCode (str): The error code of the received error.
			ErrorType (str): The type of the error received.
			Flags (str): Select the meter configuration flags from the list.
			LastErrorCode (str): The Last error code of the received error.
			LastErrorType (str): The type of the Last error received.
			Latency (number): The latency measurement for the OpenFlow channel in microseconds.
			LocalIp (str): Indicates the local IP of the Controller.
			MeterId (number): Specifies Meter ID
			NegotiatedVersion (str): Version of the protocol that has been negotiated between OpenFLow Controller and Switch.
			NumberOfBands (number): Specify the number of Bands for this controller configuration. The default value is 1.
			RemoteIp (str): The Remote IP address of the selected interface.
			ReplyState (str): The state of reply for the Open Flow channel.

		Returns:
			self: This instance with matching meterConfigStatsLearnedInformation data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of meterConfigStatsLearnedInformation data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the meterConfigStatsLearnedInformation data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PimV6JoinPruneList(Base):
	"""The PimV6JoinPruneList class encapsulates a required pimV6JoinPruneList node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PimV6JoinPruneList property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'pimV6JoinPruneList'

	def __init__(self, parent):
		super(PimV6JoinPruneList, self).__init__(parent)

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableFlapInfo(self):
		"""If selected, enables this Source entry for use in PIM-SM Register messages.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableFlapInfo')

	@property
	def EnablePack(self):
		"""If enabled, Multiple Groups can be included within a single packet.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePack')

	@property
	def FlapInterval(self):
		"""(in seconds) Specifies the amount of time between emulated flap events. The default is 60 seconds.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flapInterval')

	@property
	def GroupAddressCount(self):
		"""The number of multicast group addresses to be included in the multicast group range. The maximum number of valid possible addresses depends on the values for the Group Address and the Group Mask Width. The default value is 1.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupAddressCount')

	@property
	def GroupV6Address(self):
		"""An IPv6 address-used with the Group Mask to create a range of multicast addresses.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupV6Address')

	@property
	def GroupV6MaskWidth(self):
		"""The number of bits in the mask applied to the Group Address. (The masked bits in the Group Address form the address prefix.) The default value is 32. The valid range is 1 to 128, depending on address family type.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('groupV6MaskWidth')

	@property
	def LocalRouterId(self):
		"""The PIM-SM Router ID value, in IPv4 format.

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterId')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PruneSourceAddressCount(self):
		"""The number of Prune Source addresses to be included. The maximum number of valid possible addresses depends on the values for the Source Address and the Source Mask Width. The default value is 0. ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pruneSourceAddressCount')

	@property
	def PruneSourceV6Address(self):
		"""ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages. (Multicast addresses are invalid.)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pruneSourceV6Address')

	@property
	def PruneSourceV6MaskWidth(self):
		"""The number of bits in the mask applied to the Prune Source Address. (The masked bits in the Prune Source Address form the address prefix.) The default value is 32. The valid range is 1 to 128, depending on address family type. ONLY used for (*,G) Type to send (S,G,rpt) Prune Messages.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pruneSourceV6MaskWidth')

	@property
	def RangeType(self):
		"""The Multicast Range Type. Choose one of: (*, *, RP)-Wildcard Group Set. For (*,*, RP) Join/Prune messages. Refers to all Groups associated with this specific RP. (*, G)-Group Specific type. For (*,G) Join/Prune messages. Refers to all sources associated with a specific Group G on the RP tree. (S, G)-Source specific type. For (S,G) Join/Prune messages. Refers only to specific combination of Source S and Group G. (*, G) -> (S, G)-Switchover type. (For switchover from non-source specific group state to source-specific group state.) Register Triggered (S,G)-These are the ranges of multicast group address and unicast source address to which a PIM-SM Router emulating an RP (for those source-group combinations) will send Triggered (S,G) joins and Register-Stop messages after receiving Register messages.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rangeType')

	@property
	def RegisterStopTriggerCount(self):
		"""Available ONLY for use with Register Triggered (S,G) Range Type. (Default = 10)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('registerStopTriggerCount')

	@property
	def RpV6Address(self):
		"""The IP address of the Rendezvous Point (RP) router-the root of the RP shared multicast distribution tree (RPT).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rpV6Address')

	@property
	def SourceAddressCount(self):
		"""The number of multicast source addresses to be included. The maximum number of valid possible addresses depends on the values for the Source Address and the Source Mask Width. The default value is 0.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sourceAddressCount')

	@property
	def SourceGroupMappingType(self):
		"""Choose one of: Fully-meshed, One-to-One

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sourceGroupMappingType')

	@property
	def SourceV6Address(self):
		"""The Multicast Source Address. Used for (S,G) Type and (S,G, rpt) only. (Multicast addresses are invalid.)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sourceV6Address')

	@property
	def SourceV6MaskWidth(self):
		"""The number of bits in the mask applied to the Source Address. (The masked bits in the Source Address form the address prefix.) The default value is 32. The valid range is 1 to 128, depending on address family type. Used for (S,G) Type and (S,G, rpt) only.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sourceV6MaskWidth')

	@property
	def Status(self):
		"""Status

		Returns:
			list(str[join|leave|none|notStarted])
		"""
		return self._get_attribute('status')

	@property
	def SwitchOverInterval(self):
		"""(in seconds) The time interval allowed for the switch from using the RP tree to using a Source-specific tree-from (*,G) to (S,G). The default value is 0.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('switchOverInterval')

	def update(self, Name=None):
		"""Updates a child instance of pimV6JoinPruneList on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, EnableFlapInfo=None, EnablePack=None, FlapInterval=None, GroupAddressCount=None, GroupV6Address=None, GroupV6MaskWidth=None, PruneSourceAddressCount=None, PruneSourceV6Address=None, PruneSourceV6MaskWidth=None, RangeType=None, RegisterStopTriggerCount=None, RpV6Address=None, SourceAddressCount=None, SourceGroupMappingType=None, SourceV6Address=None, SourceV6MaskWidth=None, SwitchOverInterval=None):
		"""Base class infrastructure that gets a list of pimV6JoinPruneList device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			EnableFlapInfo (str): optional regex of enableFlapInfo
			EnablePack (str): optional regex of enablePack
			FlapInterval (str): optional regex of flapInterval
			GroupAddressCount (str): optional regex of groupAddressCount
			GroupV6Address (str): optional regex of groupV6Address
			GroupV6MaskWidth (str): optional regex of groupV6MaskWidth
			PruneSourceAddressCount (str): optional regex of pruneSourceAddressCount
			PruneSourceV6Address (str): optional regex of pruneSourceV6Address
			PruneSourceV6MaskWidth (str): optional regex of pruneSourceV6MaskWidth
			RangeType (str): optional regex of rangeType
			RegisterStopTriggerCount (str): optional regex of registerStopTriggerCount
			RpV6Address (str): optional regex of rpV6Address
			SourceAddressCount (str): optional regex of sourceAddressCount
			SourceGroupMappingType (str): optional regex of sourceGroupMappingType
			SourceV6Address (str): optional regex of sourceV6Address
			SourceV6MaskWidth (str): optional regex of sourceV6MaskWidth
			SwitchOverInterval (str): optional regex of switchOverInterval

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Join(self, *args, **kwargs):
		"""Executes the join operation on the server.

		Join

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		join()

		join(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		join(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		join(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('join', payload=payload, response_object=None)

	def Leave(self, *args, **kwargs):
		"""Executes the leave operation on the server.

		Leave

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		leave()

		leave(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		leave(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		leave(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('leave', payload=payload, response_object=None)

	def ResumePeriodicJoin(self, *args, **kwargs):
		"""Executes the resumePeriodicJoin operation on the server.

		Resume Periodic Join

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		resumePeriodicJoin()

		resumePeriodicJoin(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		resumePeriodicJoin(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		resumePeriodicJoin(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumePeriodicJoin', payload=payload, response_object=None)

	def StopPeriodicJoin(self, *args, **kwargs):
		"""Executes the stopPeriodicJoin operation on the server.

		Stop Periodic Join

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopPeriodicJoin()

		stopPeriodicJoin(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopPeriodicJoin(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stopPeriodicJoin(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopPeriodicJoin', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ldp(Base):
	"""The Ldp class encapsulates a required ldp node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ldp property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'ldp'

	def __init__(self, parent):
		super(Ldp, self).__init__(parent)

	@property
	def Router(self):
		"""An instance of the Router class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.router.Router)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.router import Router
		return Router(self)

	@property
	def EnableDiscardSelfAdvFecs(self):
		"""Discards learned labels from the DUT that match any of the enabled configured IPv4 FEC ranges.

		Returns:
			bool
		"""
		return self._get_attribute('enableDiscardSelfAdvFecs')
	@EnableDiscardSelfAdvFecs.setter
	def EnableDiscardSelfAdvFecs(self, value):
		self._set_attribute('enableDiscardSelfAdvFecs', value)

	@property
	def EnableHelloJitter(self):
		"""Allows staggered transmission of many HELLO messages.

		Returns:
			bool
		"""
		return self._get_attribute('enableHelloJitter')
	@EnableHelloJitter.setter
	def EnableHelloJitter(self, value):
		self._set_attribute('enableHelloJitter', value)

	@property
	def EnableLabelExchangeOverLsp(self):
		"""DEPRECATED Enables the ability to exchange labels over LSP for VPNs.

		Returns:
			bool
		"""
		return self._get_attribute('enableLabelExchangeOverLsp')
	@EnableLabelExchangeOverLsp.setter
	def EnableLabelExchangeOverLsp(self, value):
		self._set_attribute('enableLabelExchangeOverLsp', value)

	@property
	def EnableVpnLabelExchangeOverLsp(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableVpnLabelExchangeOverLsp')
	@EnableVpnLabelExchangeOverLsp.setter
	def EnableVpnLabelExchangeOverLsp(self, value):
		self._set_attribute('enableVpnLabelExchangeOverLsp', value)

	@property
	def Enabled(self):
		"""DEPRECATED Enables or disables the use of this emulated LDP router in the emulated LDP network. (default = disabled)

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def HelloHoldTime(self):
		"""DEPRECATED One of the timers associated with maintaining adjacencies based on hello messages.

		Returns:
			number
		"""
		return self._get_attribute('helloHoldTime')
	@HelloHoldTime.setter
	def HelloHoldTime(self, value):
		self._set_attribute('helloHoldTime', value)

	@property
	def HelloInterval(self):
		"""DEPRECATED One of the timers associated with maintaining adjacencies based on hello messages.

		Returns:
			number
		"""
		return self._get_attribute('helloInterval')
	@HelloInterval.setter
	def HelloInterval(self, value):
		self._set_attribute('helloInterval', value)

	@property
	def KeepAliveHoldTime(self):
		"""DEPRECATED One of the timers associated with maintaining adjacencies based on PDU and keep-alive messages.

		Returns:
			number
		"""
		return self._get_attribute('keepAliveHoldTime')
	@KeepAliveHoldTime.setter
	def KeepAliveHoldTime(self, value):
		self._set_attribute('keepAliveHoldTime', value)

	@property
	def KeepAliveInterval(self):
		"""DEPRECATED One of the timers associated with maintaining adjacencies based on PDU and keep-alive messages.

		Returns:
			number
		"""
		return self._get_attribute('keepAliveInterval')
	@KeepAliveInterval.setter
	def KeepAliveInterval(self, value):
		self._set_attribute('keepAliveInterval', value)

	@property
	def P2mpCapabilityParam(self):
		"""DEPRECATED The P2MP capability parameter value in hexadecimal.

		Returns:
			number
		"""
		return self._get_attribute('p2mpCapabilityParam')
	@P2mpCapabilityParam.setter
	def P2mpCapabilityParam(self, value):
		self._set_attribute('p2mpCapabilityParam', value)

	@property
	def P2mpFecType(self):
		"""DEPRECATED The MLDP P2MP FEC type value in hexadecimal.

		Returns:
			number
		"""
		return self._get_attribute('p2mpFecType')
	@P2mpFecType.setter
	def P2mpFecType(self, value):
		self._set_attribute('p2mpFecType', value)

	@property
	def RunningState(self):
		"""DEPRECATED The current state of the LDP server.

		Returns:
			str(unknown|stopped|stopping|starting|started)
		"""
		return self._get_attribute('runningState')

	@property
	def TargetedHelloInterval(self):
		"""DEPRECATED One of the timers associated with maintaining targeted peer adjacencies based on hello messages.

		Returns:
			number
		"""
		return self._get_attribute('targetedHelloInterval')
	@TargetedHelloInterval.setter
	def TargetedHelloInterval(self, value):
		self._set_attribute('targetedHelloInterval', value)

	@property
	def TargetedHoldTime(self):
		"""DEPRECATED One of the timers associated with maintaining targeted peer adjacencies based on hello messages.

		Returns:
			number
		"""
		return self._get_attribute('targetedHoldTime')
	@TargetedHoldTime.setter
	def TargetedHoldTime(self, value):
		self._set_attribute('targetedHoldTime', value)

	@property
	def UseTransportLabelsForMplsOam(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('useTransportLabelsForMplsOam')
	@UseTransportLabelsForMplsOam.setter
	def UseTransportLabelsForMplsOam(self, value):
		self._set_attribute('useTransportLabelsForMplsOam', value)

	def update(self, EnableDiscardSelfAdvFecs=None, EnableHelloJitter=None, EnableLabelExchangeOverLsp=None, EnableVpnLabelExchangeOverLsp=None, Enabled=None, HelloHoldTime=None, HelloInterval=None, KeepAliveHoldTime=None, KeepAliveInterval=None, P2mpCapabilityParam=None, P2mpFecType=None, TargetedHelloInterval=None, TargetedHoldTime=None, UseTransportLabelsForMplsOam=None):
		"""Updates a child instance of ldp on the server.

		Args:
			EnableDiscardSelfAdvFecs (bool): Discards learned labels from the DUT that match any of the enabled configured IPv4 FEC ranges.
			EnableHelloJitter (bool): Allows staggered transmission of many HELLO messages.
			EnableLabelExchangeOverLsp (bool): Enables the ability to exchange labels over LSP for VPNs.
			EnableVpnLabelExchangeOverLsp (bool): NOT DEFINED
			Enabled (bool): Enables or disables the use of this emulated LDP router in the emulated LDP network. (default = disabled)
			HelloHoldTime (number): One of the timers associated with maintaining adjacencies based on hello messages.
			HelloInterval (number): One of the timers associated with maintaining adjacencies based on hello messages.
			KeepAliveHoldTime (number): One of the timers associated with maintaining adjacencies based on PDU and keep-alive messages.
			KeepAliveInterval (number): One of the timers associated with maintaining adjacencies based on PDU and keep-alive messages.
			P2mpCapabilityParam (number): The P2MP capability parameter value in hexadecimal.
			P2mpFecType (number): The MLDP P2MP FEC type value in hexadecimal.
			TargetedHelloInterval (number): One of the timers associated with maintaining targeted peer adjacencies based on hello messages.
			TargetedHoldTime (number): One of the timers associated with maintaining targeted peer adjacencies based on hello messages.
			UseTransportLabelsForMplsOam (bool): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Start(self):
		"""Executes the start operation on the server.

		Starts the LDP protocol on a port or group of ports.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the LDP protocol on a port of group of ports simultaneously.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)
